@@ -7,7 +7,6 @@ from migrate.changeset.schema import _ColumnDelta
 from sqlalchemy.databases import information_schema
 
 import migrate
-from migrate.run import driver
 
 class TestAddDropColumn(fixture.DB):
     level=fixture.DB.CONNECT
@@ -16,30 +15,32 @@ class TestAddDropColumn(fixture.DB):
     table_name = 'tmp_adddropcol'
     table_int = 0
 
-    def setUp(self):
-        if self.url.startswith('sqlite://'):
-            self.engine = create_engine(self.url)
-        #self.engine.echo=True
+    def _setup(self, url):
+        super(TestAddDropColumn, self)._setup(url)
         self.meta.clear()
         self.table = Table(self.table_name,self.meta,
             Column('id',Integer,primary_key=True),
         )
-        super(TestAddDropColumn,self).setUp()
         self.meta.bind = self.engine
         if self.engine.has_table(self.table.name):
             self.table.drop()
         self.table.create()
-    def tearDown(self):
-        super(TestAddDropColumn,self).tearDown()
+
+    def _teardown(self):
         if self.engine.has_table(self.table.name):
-            self.table.drop()
+            try:
+                self.table.drop()
+            except:
+                pass
         self.meta.clear()
+        super(TestAddDropColumn,self)._teardown()
 
     def run_(self,create_column_func,drop_column_func,*col_p,**col_k):
         col_name = 'data'
 
         def _assert_numcols(expected,type_):
             result = len(self.table.c)
+            
             self.assertEquals(result,expected,
                 "# %s cols incorrect: %s != %s"%(type_,result,expected))
             if not col_k.get('primary_key',None):
@@ -53,12 +54,14 @@ class TestAddDropColumn(fixture.DB):
             # Changed: create/drop shouldn't mess with the objects
             #_assert_numcols(expected,'object')
             # Detect # database cols via autoload
-            self.meta.clear()
+            #self.meta.clear()
+            del self.meta.tables[self.table_name]
             self.table=Table(self.table_name,self.meta,autoload=True)
             _assert_numcols(expected,'database')
+            
         assert_numcols(1)
         if len(col_p) == 0:
-            col_p = [String]
+            col_p = [String(40)]
         col = Column(col_name,*col_p,**col_k)
         create_column_func(col)
         #create_column(col,self.table)
@@ -66,10 +69,6 @@ class TestAddDropColumn(fixture.DB):
         self.assertEquals(getattr(self.table.c,col_name),col)
         #drop_column(col,self.table)
         col = getattr(self.table.c,col_name)
-        # SQLite can't do drop column: stop here
-        if self.url.startswith('sqlite://'):
-            self.assertRaises(changeset.exceptions.NotSupportedError,drop_column_func,col)
-            return
         drop_column_func(col)
         assert_numcols(1)
 
@@ -157,11 +156,11 @@ class TestAddDropColumn(fixture.DB):
         reftable = Table('tmp_ref',self.meta,
             Column('id',Integer,primary_key=True),
         )
+        # create FK's target
+        if self.engine.has_table(reftable.name):
+            reftable.drop()
+        reftable.create()
         def add_func(col):
-            # create FK's target
-            if self.engine.has_table(reftable.name):
-                reftable.drop()
-            reftable.create()
             self.table.append_column(col)
             return create_column(col.name,self.table)
         def drop_func(col):
@@ -169,7 +168,8 @@ class TestAddDropColumn(fixture.DB):
             if self.engine.has_table(reftable.name):
                 reftable.drop()
             return ret
-        return self.run_(add_func,drop_func,Integer,ForeignKey('tmp_ref.id'))
+        return self.run_(add_func,drop_func,Integer,
+                         ForeignKey(reftable.c.id))
 
     #@fixture.usedb()
     #def xtest_pk(self):
@@ -187,7 +187,8 @@ class TestRename(fixture.DB):
     level=fixture.DB.CONNECT
     meta = MetaData()
 
-    def setUp(self):
+    def _setup(self, url):
+        super(TestRename, self)._setup(url)
         self.meta.bind = self.engine #self.meta.connect(self.engine)
 
     @fixture.usedb()
@@ -274,12 +275,12 @@ class TestColumnChange(fixture.DB):
     level=fixture.DB.CONNECT
     table_name = 'tmp_colchange'
 
-    def setUp(self):
-        fixture.DB.setUp(self)
+    def _setup(self, url):
+        super(TestColumnChange, self)._setup(url)
         self.meta = MetaData(self.engine)
         self.table = Table(self.table_name,self.meta,
             Column('id',Integer,primary_key=True),
-            Column('data',String(40),PassiveDefault("tluafed"),nullable=True),
+            Column('data',String(40),server_default=DefaultClause("tluafed"),nullable=True),
         )
         if self.table.exists():
             self.table.drop()
@@ -289,30 +290,18 @@ class TestColumnChange(fixture.DB):
             # SQLite: database schema has changed
             if not self.url.startswith('sqlite://'):
                 raise
-        #self.engine.echo=True
-    def tearDown(self):
-        #self.engine.echo=False
-        if self.table:
+    def _teardown(self):
+        if self.table.exists():
             try:
-                self.table.drop()
+                self.table.drop(self.engine)
             except sqlalchemy.exceptions.SQLError,e:
                 # SQLite: database schema has changed
                 if not self.url.startswith('sqlite://'):
                     raise
-        fixture.DB.tearDown(self)
+        #self.engine.echo=False
+        super(TestColumnChange, self)._teardown()
 
-    @fixture.usedb(supported='sqlite')
-    def test_sqlite_not_supported(self):
-        self.assertRaises(changeset.exceptions.NotSupportedError,
-            self.table.c.data.alter,default=PassiveDefault('tluafed'))
-        self.assertRaises(changeset.exceptions.NotSupportedError,
-            self.table.c.data.alter,nullable=True)
-        self.assertRaises(changeset.exceptions.NotSupportedError,
-            self.table.c.data.alter,type=String(21))
-        self.assertRaises(changeset.exceptions.NotSupportedError,
-            self.table.c.data.alter,name='atad')
-
-    @fixture.usedb(not_supported='sqlite')
+    @fixture.usedb()
     def test_rename(self):
         """Can rename a column"""
         def num_rows(col,content):
@@ -339,7 +328,7 @@ class TestColumnChange(fixture.DB):
         self.assertEquals(num_rows(self.table.c.data,content),1)
 
         # ...as a function, given a new object
-        col = Column('atad',String(40),default=self.table.c.data.default)
+        col = Column('atad',String(40),server_default=self.table.c.data.server_default)
         alter_column(self.table.c.data, col)
         self.refresh_table(self.table.name)
         self.assert_('data' not in self.table.c.keys())
@@ -347,14 +336,14 @@ class TestColumnChange(fixture.DB):
         self.assertEquals(num_rows(self.table.c.atad,content),1)
 
         # ...as a method, given a new object
-        col = Column('data',String(40),default=self.table.c.atad.default)
+        col = Column('data',String(40),server_default=self.table.c.atad.server_default)
         self.table.c.atad.alter(col)
         self.refresh_table(self.table.name)
         self.assert_('atad' not in self.table.c.keys())
         self.table.c.data   # Should not raise exception
         self.assertEquals(num_rows(self.table.c.data,content),1)
         
-    @fixture.usedb(not_supported='sqlite')
+    @fixture.usedb()
     def xtest_fk(self):
         """Can add/drop foreign key constraints to/from a column
         Not supported
@@ -371,7 +360,7 @@ class TestColumnChange(fixture.DB):
         self.refresh_table(self.table.name)
         self.assert_(self.table.c.data.foreign_key is None)
 
-    @fixture.usedb(not_supported='sqlite')
+    @fixture.usedb()
     def test_type(self):
         """Can change a column's type"""
         # Entire column definition given
@@ -394,40 +383,40 @@ class TestColumnChange(fixture.DB):
         self.refresh_table(self.table.name)
         self.assert_(isinstance(self.table.c.id.type,String))
 
-    @fixture.usedb(not_supported='sqlite')
+    @fixture.usedb(not_supported='mysql')
     def test_default(self):
-        """Can change a column's default value (PassiveDefaults only)
-        Only PassiveDefaults are changed here: others are managed by the 
+        """Can change a column's server_default value (DefaultClauses only)
+        Only DefaultClauses are changed here: others are managed by the 
         application / by SA
         """
         #self.engine.echo=True
-        self.assertEquals(self.table.c.data.default.arg,'tluafed')
+        self.assertEquals(self.table.c.data.server_default.arg,'tluafed')
 
-        # Just the new default
+        # Just the new default 
         default = 'my_default'
-        self.table.c.data.alter(default=PassiveDefault(default))
+        self.table.c.data.alter(server_default=DefaultClause(default))
         self.refresh_table(self.table.name)
-        #self.assertEquals(self.table.c.data.default.arg,default)
+        #self.assertEquals(self.table.c.data.server_default.arg,default)
         # TextClause returned by autoload
-        self.assert_(default in str(self.table.c.data.default.arg))
+        self.assert_(default in str(self.table.c.data.server_default.arg))
 
         # Column object
         default = 'your_default'
-        self.table.c.data.alter(Column('data',String(40),default=PassiveDefault(default)))
+        self.table.c.data.alter(Column('data',String(40),server_default=DefaultClause(default)))
         self.refresh_table(self.table.name)
-        self.assert_(default in str(self.table.c.data.default.arg))
+        self.assert_(default in str(self.table.c.data.server_default.arg))
 
         # Remove default
-        self.table.c.data.alter(default=None)
+        self.table.c.data.alter(server_default=None)
         self.refresh_table(self.table.name)
-        # default isn't necessarily None for Oracle
-        #self.assert_(self.table.c.data.default is None,self.table.c.data.default)
+        # server_default isn't necessarily None for Oracle
+        #self.assert_(self.table.c.data.server_default is None,self.table.c.data.server_default)
         self.engine.execute(self.table.insert(),id=11)
         row = self.table.select().execute().fetchone()
         self.assert_(row['data'] is None,row['data'])
         
 
-    @fixture.usedb(not_supported='sqlite')
+    @fixture.usedb()
     def test_null(self):
         """Can change a column's null constraint"""
         self.assertEquals(self.table.c.data.nullable,True)
@@ -443,11 +432,12 @@ class TestColumnChange(fixture.DB):
         self.refresh_table(self.table.name)
         self.assertEquals(self.table.c.data.nullable,True)
 
-    @fixture.usedb(not_supported='sqlite')
+    @fixture.usedb()
     def xtest_pk(self):
         """Can add/drop a column to/from its table's primary key
         Not supported
         """
+        self.engine.echo = True
         self.assertEquals(len(self.table.primary_key),1)
 
         # Entire column definition
@@ -508,8 +498,3 @@ class TestColumnDelta(fixture.Base):
         verify(['default'],mkcol(default=None),mkcol(default='42'))
         verify([],mkcol(default=None),mkcol(default=None))
         verify([],mkcol(default='42'),mkcol(default='42'))
-
-class TestDriver(fixture.DB):
-    @fixture.usedb()
-    def test_driver(self):
-        self.assertEquals(self.url.split(':',1)[0],driver(self.engine))
